@@ -1,11 +1,10 @@
-#!/usr/share/ucs-test/runner /usr/bin/py.test-3 -svvv
+#!/usr/share/ucs-test/runner pytest-3 -svvv
 ## desc: Test setting the quota through pam with usrquota
 ## roles-not: [basesystem]
 ## exposure: dangerous
 ## packages:
 ##   - univention-quota
 
-from __future__ import print_function
 from quota_test import QuotaCheck
 
 
