@@ -8,8 +8,8 @@ import os
 import signal
 import subprocess
 import time
-from argparse import ArgumentParser, Namespace, _ArgumentGroup  # noqa F401
-from typing import Any, Callable, List  # noqa F401
+from argparse import ArgumentParser, Namespace, _ArgumentGroup  # noqa: F401
+from typing import Any, Callable, List  # noqa: F401
 
 import six
 
